@@ -25,21 +25,21 @@ of Technology shall not be used in advertising or otherwise to promote
 the sale, use or other dealings in this Software without prior written
 authorization from Illinois Institute of Technology.
 """
-import matplotlib.pyplot as plt
-import fabio
-import pyFAI
-from lmfit import Parameters
-from lmfit.models import VoigtModel
+
 from os import makedirs
 from os.path import isfile, exists
 import pickle
-from ..utils.file_manager import fullPath
+import matplotlib.pyplot as plt
+from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
+from lmfit import Parameters
+from lmfit.models import VoigtModel
+import fabio
+import musclex
+from ..utils.file_manager import fullPath, ifHdfReadConvertless
 from ..utils.image_processor import *
 from ..utils.histogram_processor import *
-import musclex
-from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
 
-class DiffractionCentroids():
+class DiffractionCentroids:
     """
     A class for Diffraction Centroids processing - go to process() to see all processing steps
     """
@@ -52,7 +52,7 @@ class DiffractionCentroids():
         :param fixRanges: fixed peak ranges configured my users
         :param off_mer: configuration of off-meridian peaks configured my users
         """
-        self.avgImg = self.mergeImages(dir_path, imgList) # avarage all image in a group
+        self.avgImg = self.mergeImages(dir_path, imgList) # average all image in a group
         if self.avgImg.shape == (1043, 981):
             self.img_type = "PILATUS"
         else:
@@ -82,6 +82,7 @@ class DiffractionCentroids():
         for fname in imgList:
             fullname = fullPath(dir_path, fname)
             img = fabio.open(fullname).data
+            img = ifHdfReadConvertless(fname, img)
             imgList2.append(img)
         return np.mean(imgList2, axis=0)
 
@@ -99,7 +100,7 @@ class DiffractionCentroids():
 
         if isfile(cachefile):
             cinfo = pickle.load(open(cachefile, "rb"))
-            if cinfo != None:
+            if cinfo is not None:
                 if cinfo['program_version'] == self.version:
                     info = cinfo
                 else:
@@ -150,6 +151,11 @@ class DiffractionCentroids():
             del self.info[k]
 
     def updateInfo(self, flags):
+        """
+        Update info dict using flags
+        :param flags: flags
+        :return: -
+        """
         if flags['orientation_model'] is None:
             if 'orientation_model' not in self.info:
                 flags['orientation_model'] = 0
@@ -204,7 +210,7 @@ class DiffractionCentroids():
         npt_rad = int(round(max([distance(center, c) for c in corners])))
         ai = AzimuthalIntegrator(detector=det)
         ai.setFit2D(100, center[0], center[1])
-        tth, I = ai.integrate1d(img, npt_rad, unit="r_mm", method="csr")
+        _, I = ai.integrate1d(img, npt_rad, unit="r_mm", method="csr")
         self.info['rmin'] = getFirstVallay(I)
         print("R-min = "+str(self.info['rmin']))
         self.removeInfo('int_area')
@@ -262,13 +268,13 @@ class DiffractionCentroids():
             angle = self.info['rotationAngle']
         if '90rotation' in self.info and self.info['90rotation'] is True:
             angle = angle - 90 if angle > 90 else angle + 90
-            
+
         center = self.info["center"]
         if "orig_center" in self.info:
             center = self.info["orig_center"]
         else:
             self.info["orig_center"] = center
-        
+
         rotImg, self.info["center"], self.rotMat = rotateImage(img, center, angle, self.img_type, self.mask_thres)
 
         return rotImg
@@ -415,11 +421,10 @@ class DiffractionCentroids():
 
                 if abs(p-new_peak) < 4:
                     break
-                else:
-                    left = min(p, new_peak)
-                    right = max(p, new_peak)
-                    if all(smooth_hist[left+1:right] > p):
-                        break
+                left = min(p, new_peak)
+                right = max(p, new_peak)
+                if all(smooth_hist[left+1:right] > p):
+                    break
                 dist = dist/2
             peakList.append(new_peak)
         return sorted(list(set(peakList)))
@@ -468,15 +473,16 @@ class DiffractionCentroids():
         print("Bottom centroids = " + str(self.info['bottom_centroids']))
 
     def fitModel(self, hist, peaks, baselines):
-        # JUST FOR TEST
-        # Fit Voigt model to histogram using peaks and baselines
-        # Currently, this function is not used by any process
+        """
+        JUST FOR TEST
+        Fit Voigt model to histogram using peaks and baselines
+        Currently, this function is not used by any process
+        """
         new_hist = np.zeros(len(hist))
         pars = Parameters()
         mean_margin = 3
 
-        for i in range(len(peaks)):
-            p = peaks[i]
+        for (i, p) in enumerate(peaks):
             baseline = baselines[i]
             width, _ = getWidth(hist, p, baseline)
             new_hist[p - width:p + width] = hist[p - width:p + width]
@@ -588,6 +594,9 @@ class DiffractionCentroids():
         return top_hist, top_ignore, bottom_hist, bottom_ignore
 
     def getOffMerRminmax(self):
+        """
+        Produce Rmin and Rmax of off-meridian ranges.
+        """
         if 'off_mer_rmin_rmax' not in self.info:
             if 'fixed_offmer_hull_range' in self.info:
                 self.info['off_mer_rmin_rmax'] = self.info['fixed_offmer_hull_range']
@@ -706,7 +715,6 @@ class DiffractionCentroids():
         Save info dict to cache. Cache file will be save as filename.info in folder "qf_cache"
         :return: -
         """
-
         cache_path = fullPath(self.dir_path, 'dc_cache')
 
         if not exists(cache_path):
