@@ -26,29 +26,28 @@ the sale, use or other dealings in this Software without prior written
 authorization from Illinois Institute of Technology.
 """
 
-# import cv2.cv as cv
 import os
+from os import makedirs
+from os.path import isfile, exists
+import numpy as np
 import json
+import pickle
 import tifffile
 from lmfit import Model, Parameters
 from lmfit.models import VoigtModel, GaussianModel
 from sklearn.metrics import r2_score, mean_squared_error
-import pickle
+from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
 import fabio
-# import pyFAI
-from os.path import isfile, exists
-from os import makedirs
-from ..utils.file_manager import fullPath, getBlankImageAndMask, getMaskOnly
+import musclex
+from ..utils.file_manager import fullPath, getBlankImageAndMask, getMaskOnly, ifHdfReadConvertless
 from ..utils.histogram_processor import *
 from ..utils.image_processor import *
-import musclex
-from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
 
 class EquatorImage:
     """
     A class for Bio-Muscle processing - go to process() to see all processing steps
     """
-    def __init__(self, dir_path, filename, parent):
+    def __init__(self, dir_path, filename, parent, file_list=None, extension=''):
         """
         Initial value for EquatorImage object
         :param dir_path: directory path of input image
@@ -57,8 +56,15 @@ class EquatorImage:
         self.sigmaS = 0.0001
         self.dir_path = dir_path
         self.filename = filename
-        self.orig_img = fabio.open(fullPath(dir_path, filename)).data
-        self.orig_img=self.orig_img.astype("int32")
+        if extension in ('.hdf5', '.h5'):
+            index = next((i for i, item in enumerate(file_list[0]) if item == filename), 0)
+            self.orig_img = file_list[1][index]
+        else:
+            self.orig_img = fabio.open(fullPath(dir_path, filename)).data
+        self.orig_img = ifHdfReadConvertless(self.filename, self.orig_img)
+        self.orig_img = self.orig_img.astype("float32")
+        self.image = None
+        self.skeletalVarsNotSet = False
         if self.orig_img.shape == (1043, 981):
             self.img_type = "PILATUS"
         else:
@@ -71,7 +77,7 @@ class EquatorImage:
                     metadata = tif.pages[0].tags["ImageDescription"].value
             try:
                 self.quadrant_folded, self.initialImgDim = json.loads(metadata)
-            except:
+            except Exception:
                 print(filename, " file is not quadrant folded")
 
         self.rotated_img = None
@@ -85,9 +91,12 @@ class EquatorImage:
             }
         else:
             self.info = cache
-        self.parent = parent
+        if parent is not None:
+            self.parent = parent
+        else:
+            self.parent = self
 
-    def process(self, settings, paramInfo):
+    def process(self, settings, paramInfo=None):
         """
         All processing steps - all settings are provided by bio-muscle app as a dictionary
         settings must have ...
@@ -122,16 +131,20 @@ class EquatorImage:
         :param k: key of dictionary
         :return: -
         """
-
         if k is None:
             keys = list(self.info.keys())
-            for k in keys:
-                del self.info[k]
+            for key in keys:
+                del self.info[key]
         else:
-            if k in self.info.keys(): # remove from dictionary if the key exists
+            if k in self.info: # remove from dictionary if the key exists
                 del self.info[k]
 
     def updateInfo(self, settings):
+        """
+        Update info dict using settings
+        :param settings: calibration settings
+        :return: -
+        """
         if settings['orientation_model'] is None:
             if 'orientation_model' not in self.info or self.info['orientation_model'] is None:
                 settings['orientation_model'] = 0
@@ -154,7 +167,7 @@ class EquatorImage:
                 img[mask>0] = self.info['mask_thres']-1
             if maskOnly is not None:
                 print("Applying mask only image")
-                img[maskOnly>0] = self.info['mask_thres']-1 
+                img[maskOnly>0] = self.info['mask_thres']-1
 
         self.image = img
 
@@ -204,7 +217,7 @@ class EquatorImage:
             self.removeInfo('rmin')  # Remove R-min from info dict to make it be re-calculated
 
         if "mode_angle" in self.info:
-            print("Using mode orientation {}".format(self.info["mode_angle"]))
+            print(f'Using mode orientation {self.info["mode_angle"]}')
             self.info['rotationAngle'] = self.info["mode_angle"]
 
         print("Done. Rotation Angle is " + str(self.info['rotationAngle']))
@@ -234,18 +247,9 @@ class EquatorImage:
             npt_rad = int(round(max([distance(center, c) for c in corners])))
             ai = AzimuthalIntegrator(detector=det)
             ai.setFit2D(100, center[0], center[1])
-            tth, I = ai.integrate1d(img, npt_rad, unit="r_mm", method="csr") # Get 1D Azimuthal integrated histogram
+            _, I = ai.integrate1d(img, npt_rad, unit="r_mm", method="csr") # Get 1D Azimuthal integrated histogram
             self.info['rmin'] = getFirstVallay(I) # R-min is value before the first valley
             self.removeInfo('int_area')  # Remove integrated area from info dict to make it be re-calculated
-            #
-            # fig = plt.figure()
-            # ax = fig.add_subplot(111)
-            # ax.plot(I[:int(len(I)/4)])
-            # ax.axvline(self.info['rmin'], color = 'r')
-            # ax.set_xlabel("radius (pixel)")
-            # ax.set_ylabel("intensity (pixel)")
-            # ax.set_xlim((0, len(I[:int(len(I)/4)])))
-            # fig.show()
 
         print("Done. R-min is " + str(self.info['rmin']))
 
@@ -256,7 +260,6 @@ class EquatorImage:
         :param angle: rotation angle
         :return: rotated image
         """
-
         if img is None:
             img = copy.copy(self.image)
         if angle is None:
@@ -268,17 +271,17 @@ class EquatorImage:
             centersNotEq = self.rotated_img[0] != self.info["center"] if type(self.rotated_img[0] != self.info["center"]) == bool else (self.rotated_img[0] != self.info["center"]).any()
         if self.rotated_img is None or centersNotEq or self.rotated_img[1] != self.info["rotationAngle"] or (self.rotated_img[2] != img).any():
             # encapsulate rotated image for using later as a list of [center, angle, original image, rotated image[
-            
+
             center = self.info["center"]
             if "orig_center" in self.info:
                 center = self.info["orig_center"]
                 print("orig_center",self.info['orig_center'])
             else:
                 self.info["orig_center"] = center
-            
+
             rotImg, self.info["center"], self.rotMat = rotateImage(img, center, angle, self.img_type, self.info['mask_thres'])
             self.rotated_img = [self.info["center"], angle, img, rotImg]
-            
+
         return self.rotated_img[3]
 
     def getIntegrateArea(self):
@@ -296,7 +299,7 @@ class EquatorImage:
             else:
                 rmin = self.info['rmin']
                 img = getCenterRemovedImage(copy.copy(self.image), tuple(center), rmin) # remove center location
-                
+
                 rotate_img = self.getRotatedImage(img) # rotate image
                 center = self.info["center"] #since rotation might change center
                 init_range = int(round(rmin * 1.5)) # specify initial guess by using 150% or R-min
@@ -304,7 +307,7 @@ class EquatorImage:
                 bottom = min(int(center[1]) + init_range, rotate_img.shape[0])
                 area = rotate_img[top:bottom, :]
                 hist = np.sum(area, axis=1)  # Get the horizontal histogram from the initital area
-                hull = convexHull(hist) # Apply convexull
+                hull = convexHull(hist) # Apply convexhull
 
                 if len(hist) > 0:
                     max_loc = np.argmax(hull)
@@ -363,6 +366,13 @@ class EquatorImage:
             hist = copy.copy(self.info['hist'])
             int_area = self.info['int_area']
             img_area = self.getRotatedImage()[int_area[0]:int_area[1], :]
+            min_val = self.orig_img.min()
+            if self.img_type == "PILATUS":
+                histo = np.histogram(self.orig_img, 3, (min_val, min_val+3))
+                max_ind = np.argmax(histo[0])
+                self.info['mask_thres'] = histo[1][max_ind]
+            else:
+                self.info['mask_thres'] = min_val - 1. #getMaskThreshold(self.orig_img, self.img_type)
             ignore = np.array([any(img_area[:, i] <= self.info['mask_thres']) for i in range(img_area.shape[1])])
             if any(ignore):
                 left_ignore = ignore[:int(center[0])]
@@ -409,7 +419,6 @@ class EquatorImage:
 
         print("Done. Peaks are found : " + str(self.info['tmp_peaks']))
 
-
     def managePeaks(self):
         """
         Getting real peaks from temp peaks. Temp peaks will be considered as real peaks if it in the Hexagonal Pattern location.
@@ -469,7 +478,6 @@ class EquatorImage:
 
         # self.info['peak'] = [symP, peak]
         S10 = int((first_left + first_right) / 2.)
-
         self.info['S'] = [S10]
 
         # Find other S values based on S10 and theta function
@@ -481,7 +489,6 @@ class EquatorImage:
             SList.append(s_pos)
 
         maximum_nPeaks = 2
-
         # Find peaks correponding to S values
         for i, S in enumerate(SList):
             self.info['S'].append(S)
@@ -546,7 +553,7 @@ class EquatorImage:
             hull_hist = self.info['hulls']['all']
             x = np.arange(0, len(hull_hist))
             histNdarray = np.array(hull_hist)
-            total_area = sum(histNdarray)
+            # total_area = sum(histNdarray)
             centerX = self.info['center'][0]
 
             margin = 10.
@@ -558,10 +565,10 @@ class EquatorImage:
             params.add("S10", S[0], min=S[0] - margin, max=S[0] + margin)
             params.add("S0", S0, min=-0.001,  max=0.001)
 
-            for i in range(len(left_areas)):
-                params.add("left_area" + str(i + 1), max(left_areas[i], 100), min=0)
-            for i in range(len(right_areas)):
-                params.add("right_area" + str(i + 1), max(right_areas[i],100), min=0)
+            for (i, e) in enumerate(left_areas):
+                params.add("left_area" + str(i + 1), max(e, 100), min=0)
+            for (i, e) in enumerate(right_areas):
+                params.add("right_area" + str(i + 1), max(e, 100), min=0)
 
             left_sigmac = self.info['left_fix_sigmac'] if 'left_fix_sigmac' in self.info else self.info['left_sigmac']
 
@@ -645,6 +652,7 @@ class EquatorImage:
 
             # for method in ['leastsq', 'lbfgsb', 'powell', 'cg', 'slsqp', 'nelder', 'cobyla', 'tnc']:
             for method in ['leastsq']:
+                # WARNING this fit function might give different results depending on the operating system
                 result = model.fit(histNdarray, verbose = False, method=method, params=params, **int_vars)
                 if result is not None:
                     res = result.values
@@ -687,10 +695,6 @@ class EquatorImage:
 
                 self.info['fit_results'] = fit_result
                 self.saveParamInfo(params, int_vars, fit_result)
-                # print "cardiacFit result : ",result.values
-
-                # original_hist = self.info['rhist']
-                # plt.plot(x, original_hist, label = 'histogram_BG')
 
         if 'fit_results' in self.info:
             print("Done. Fitting Results : " + str(self.info['fit_results']))
@@ -722,7 +726,7 @@ class EquatorImage:
             paramInfo[p] = {}
             paramInfo[p]['fixed'] = True
             paramInfo[p]['val'] = int_vars[p]
-            if not isinstance(int_vars[p], bool) and (isinstance(int_vars[p], float) or isinstance(int_vars[p], int)):
+            if not isinstance(int_vars[p], bool) and isinstance(int_vars[p], (float, int)):
                 paramInfo[p]['min'] = int_vars[p] - 10
                 paramInfo[p]['max'] = int_vars[p] + 10
         self.info['paramInfo'] = paramInfo
@@ -752,7 +756,6 @@ class EquatorImage:
                 params.add(p, pinfo['val'], min=pinfo['min'], max=pinfo['max'])
 
         # When using previous fit to update
-
         S = self.info['S']
 
         left_hull = self.info['hulls']['left']
@@ -768,12 +771,12 @@ class EquatorImage:
         left_areas = [left_height[i] * left_widths[i] * np.sqrt(2 * np.pi) for i in range(len(left_peaks))]
         right_areas = [right_height[i] * right_widths[i] * np.sqrt(2 * np.pi) for i in range(len(right_peaks))]
 
-        for i in range(len(left_areas)):
+        for (i, e) in enumerate(left_areas):
             if "left_area" + str(i + 1) not in paramInfo:
-                params.add("left_area" + str(i + 1), max(left_areas[i], 100), min=0)
-        for i in range(len(right_areas)):
+                params.add("left_area" + str(i + 1), max(e, 100), min=0)
+        for (i, e) in enumerate(right_areas):
             if "right_area" + str(i + 1) not in paramInfo:
-                params.add("right_area" + str(i + 1), max(right_areas[i], 100), min=0)
+                params.add("right_area" + str(i + 1), max(e, 100), min=0)
 
         if self.info['isSkeletal'] and self.skeletalVarsNotSet:
             # If zline is checked and use previous fit used, initialize the zline parameters if not set previously
@@ -785,7 +788,6 @@ class EquatorImage:
                 params.add(side + '_intz', init_intz, min=0, max=init_intz * 4. + 1.)
                 params.add(side + '_gammaz', 8., min=-5., max=30.)
 
-
         int_vars['x'] = x
 
         # Fit model
@@ -894,7 +896,7 @@ class EquatorImage:
 
         if exists(cache_path) and isfile(cache_file):
             cinfo = pickle.load(open(cache_file, "rb"))
-            if cinfo != None:
+            if cinfo is not None:
                 if cinfo['program_version'] == self.version:
                     return cinfo
                 print("Cache version " + cinfo['program_version'] + " did not match with Program version " + self.version)
@@ -926,11 +928,18 @@ class EquatorImage:
         if exists(cache_path) and isfile(cache_file):
             os.remove(cache_file)
 
+    def statusPrint(self, text):
+        """
+        Print the text in the window or in the terminal depending on if we are using GUI or headless.
+        :param text: text to print
+        :return: -
+        """
+        print(text)
 
-def cardiacFit(x, centerX, S0, S10, model, isSkeletal, k
-               , left_sigmad, left_sigmas, left_sigmac, left_gamma, left_intz, left_sigmaz, left_zline, left_gammaz
-               , right_sigmad, right_sigmas, right_sigmac, right_gamma, right_intz, right_sigmaz, right_zline, right_gammaz, extraGaussCenter, extraGaussSig, extraGaussArea, **kwargs):
-
+def cardiacFit(x, centerX, S0, S10, model, isSkeletal, k,
+                left_sigmad, left_sigmas, left_sigmac, left_gamma, left_intz, left_sigmaz, left_zline, left_gammaz,
+                right_sigmad, right_sigmas, right_sigmac, right_gamma, right_intz, right_sigmaz, right_zline,
+                right_gammaz, extraGaussCenter, extraGaussSig, extraGaussArea, **kwargs):
     """
     Using for fitting model by lmfit
     :param x: x range (list)
@@ -949,31 +958,8 @@ def cardiacFit(x, centerX, S0, S10, model, isSkeletal, k
     :param kwargs: area1, area2, ..., areaN as parameters or areas as a list
     :return:
     """
-    # print "center=", centerX
-    # print "S10=",S10
-    # print "model=",model
-    # print "isSkeletal=",isSkeletal
-    # print "left_sigmad=", left_sigmad
-    # print "left_sigmas=", left_sigmas
-    # print "left_sigmac=", left_sigmac
-    # print "left_gamma=", left_gamma
-    # print "left_intz=", left_intz
-    # print "left_sigmaz=", left_sigmaz
-    # print "left_zline=", left_zline
-    # print "left_gammaz=", left_gammaz
-    # print "right_sigmad=", right_sigmad
-    # print "right_sigmas=", right_sigmas
-    # print "right_sigmac=", right_sigmac
-    # print "right_gamma=", right_gamma
-    # print "right_intz=", right_intz
-    # print "right_sigmaz=", right_sigmaz
-    # print "right_zline=", right_zline
-    # print "right_gammaz=", right_gammaz
-    # print "kwargs=", kwargs
-    # print "======================"
     if kwargs is not None:
-
-        if 'left_areas' in kwargs.keys() and 'right_areas' in kwargs.keys() :
+        if 'left_areas' in kwargs and 'right_areas' in kwargs:
             left_areas = kwargs['left_areas']
             right_areas = kwargs['right_areas']
         else:
@@ -992,7 +978,6 @@ def cardiacFit(x, centerX, S0, S10, model, isSkeletal, k
             right_areas = sorted(right_areas_dict.items(), key=lambda kv: kv[0])
             right_areas = [v for (_, v) in right_areas]
 
-
         speaks_dict = {}
         for k1 in range(1, max(len(left_areas), len(right_areas)) + 1):
             speaks_dict[k1] = 0
@@ -1004,8 +989,6 @@ def cardiacFit(x, centerX, S0, S10, model, isSkeletal, k
 
         Speaks = sorted(speaks_dict.items(), key=lambda kv: kv[0])
         Speaks = [v for (_, v) in Speaks]
-
-
         result = cardiacSide(model, 'left', x, centerX, S0, S10, left_sigmac, left_sigmad, left_sigmas, left_gamma, left_areas, Speaks, extraGaussCenter, extraGaussSig, extraGaussArea)
         result += cardiacSide(model, 'right', x, centerX, S0, S10, right_sigmac, right_sigmad, right_sigmas, right_gamma,
                              right_areas, Speaks, extraGaussCenter, extraGaussSig, extraGaussArea)
@@ -1022,13 +1005,15 @@ def cardiacFit(x, centerX, S0, S10, model, isSkeletal, k
                                    sigma=left_sigmaz, gamma=left_gammaz)
                 result += mod.eval(x=x, amplitude=right_intz, center=centerX + S0 - right_zline,
                                    sigma=right_sigmaz, gamma=right_gammaz)
-
         return result + k
-
     return 0
 
-def cardiacSide(model, side, x, centerX, S0, S10, sigmac, sigmad, sigmas, gamma, areas, Speak, extraGaussCenter, extraGaussSig, extraGaussArea):
-    for i, area in enumerate(areas):
+def cardiacSide(model, side, x, centerX, S0, S10, sigmac, sigmad, sigmas,
+                gamma, areas, Speak, extraGaussCenter, extraGaussSig, extraGaussArea):
+    """
+    Using for fitting model by lmfit
+    """
+    for (i, _) in enumerate(areas):
         if side == 'left':
             hk = i
             p = centerX + S0 - S10 * theta(hk) + Speak[i]
@@ -1039,16 +1024,11 @@ def cardiacSide(model, side, x, centerX, S0, S10, sigmac, sigmad, sigmas, gamma,
         sigmahk = np.sqrt(sigmac ** 2 + (sigmad * theta(hk)) ** 2 + (sigmas * (theta(hk) ** 2)) ** 2)
 
         if model == "Gaussian":
-            # if i == 0:
-            #     result = (areas[i]/sigmahk)*np.exp(-np.log(2)*((x-p)/sigmahk)**2)
-            # else:
-            #     result += (areas[i]/sigmahk)*np.exp(-np.log(2)*((x-p)/sigmahk)**2)
             mod = GaussianModel()
             if i == 0:
                 result = mod.eval(x=x, amplitude=areas[i], center=p, sigma=sigmahk)
             else:
                 result += mod.eval(x=x, amplitude=areas[i], center=p, sigma=sigmahk)
-
         elif model == "Voigt":
             mod = VoigtModel()
             if i == 0:
@@ -1081,10 +1061,8 @@ def cardiacFit_old(x, centerX, S10, sigmad, sigmas, sigmac, model, gamma, isSkel
     :return:
     """
     if kwargs is not None:
-
         result = None
-
-        if 'areas' in kwargs.keys():
+        if 'areas' in kwargs:
             areas = kwargs['areas']
         else:
             areas_dict = {}
@@ -1097,7 +1075,7 @@ def cardiacFit_old(x, centerX, S10, sigmad, sigmas, sigmac, model, gamma, isSkel
 
         nPeaks = int(len(areas)/2)
 
-        for i, area in enumerate(areas):
+        for (i, _) in enumerate(areas):
             if i < nPeaks:
                 hk = (nPeaks) - i - 1
                 p = centerX - S10 * theta(hk)
@@ -1108,10 +1086,6 @@ def cardiacFit_old(x, centerX, S10, sigmad, sigmas, sigmac, model, gamma, isSkel
             sigmahk = np.sqrt(sigmac ** 2 + (sigmad * theta(hk)) ** 2 + (sigmas * (theta(hk) ** 2)) ** 2)
 
             if model == "Gaussian":
-                # if i == 0:
-                #     result = (areas[i]/sigmahk)*np.exp(-np.log(2)*((x-p)/sigmahk)**2)
-                # else:
-                #     result += (areas[i]/sigmahk)*np.exp(-np.log(2)*((x-p)/sigmahk)**2)
                 mod = GaussianModel()
                 if i == 0:
                     result = mod.eval(x=x, amplitude=areas[i], center=p, sigma=sigmahk)
@@ -1138,13 +1112,14 @@ def cardiacFit_old(x, centerX, S10, sigmad, sigmas, sigmac, model, gamma, isSkel
                                    sigma=sigmaz, gamma=gammaz)
                 result += mod.eval(x=x, amplitude=intz, center=centerX - zline,
                                    sigma=sigmaz, gamma=gammaz)
-
         return result
-
     return 0
 
-
 def getCardiacGraph(x, fit_results):
+    """
+    Give the cardiac graph based on the fit results.
+    :param fit_results: fit results
+    """
     plot_params = {
         'centerX': fit_results['centerX'],
         'S0': fit_results["S0"],
