@@ -27,37 +27,43 @@ authorization from Illinois Institute of Technology.
 """
 
 import os
-import fabio
 import pickle
-# import pyFAI
+import fabio
+import pyFAI
 from scipy.ndimage.filters import gaussian_filter, convolve1d
-from ..utils.file_manager import fullPath, createFolder, getBlankImageAndMask, getMaskOnly
-from ..utils.histogram_processor import *
-from ..utils.image_processor import *
+from scipy.interpolate import UnivariateSpline
 from skimage.morphology import white_tophat, disk
-from tifffile import imsave
-from scipy.interpolate import UnivariateSpline, PchipInterpolator
-import musclex
 import ccp13
 from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
+import musclex
+import musclex.modules.QF_utilities as qfu
+from ..utils.file_manager import fullPath, createFolder, getBlankImageAndMask, getMaskOnly, ifHdfReadConvertless
+from ..utils.histogram_processor import *
+from ..utils.image_processor import *
 
 # Make sure the cython part is compiled
 # from subprocess import call
 # call(["python setup2.py build_ext --inplace"], shell = True)
 
-import musclex.modules.QF_utilities as qfu
-
-class QuadrantFolder(object):
+class QuadrantFolder:
     """
     A class for Quadrant Folding processing - go to process() to see all processing steps
     """
-    def __init__(self, img_path, img_name, parent):
+    def __init__(self, img_path, img_name, parent, file_list=None, extension=''):
         """
         Initial value for QuadrantFolder object
         :param img_path: directory path of input image
         :param img_name: image file name
         """
-        self.orig_img = fabio.open(fullPath(img_path, img_name)).data
+        if extension in ('.hdf5', '.h5'):
+            index = next((i for i, item in enumerate(file_list[0]) if item == img_name), 0)
+            self.orig_img = file_list[1][index]
+        else:
+            self.orig_img = fabio.open(fullPath(img_path, img_name)).data
+        self.orig_img = ifHdfReadConvertless(img_name, self.orig_img)
+        self.orig_img = self.orig_img.astype("float32")
+        self.orig_image_center = None
+        self.dl, self.db = 0, 0
         if self.orig_img.shape == (1043, 981):
             self.img_type = "PILATUS"
         else:
@@ -75,7 +81,11 @@ class QuadrantFolder(object):
         self.center_before_rotation = None # we need the center before rotation is applied each time we rotate the image
         self.rotMat = None # store the rotation matrix used so that any point specified in current co-ordinate system can be transformed to the base (original image) co-ordinate system
         self.centerChanged = False
-        self.parent = parent
+        if parent is not None:
+            self.parent = parent
+        else:
+            self.parent = self
+        self.newImgDimension = None
         self.masked = False
 
         # info dictionary will save all results
@@ -86,7 +96,6 @@ class QuadrantFolder(object):
                 'imgType' : str(self.orig_img.dtype)
             }
 
-
     def cacheInfo(self):
         """
         Save info dict to cache. Cache file will be save as filename.info in folder "qf_cache"
@@ -95,7 +104,8 @@ class QuadrantFolder(object):
         cache_file = fullPath(fullPath(self.img_path, "qf_cache"), self.img_name + ".info")
         createFolder(fullPath(self.img_path, "qf_cache"))
         self.info['program_version'] = self.version
-        pickle.dump(self.info, open(cache_file, "wb"))
+        with open(cache_file, "wb") as c:
+            pickle.dump(self.info, c)
 
     def loadCache(self):
         """
@@ -104,13 +114,13 @@ class QuadrantFolder(object):
         """
         cache_file = fullPath(fullPath(self.img_path, "qf_cache"), self.img_name+".info")
         if os.path.isfile(cache_file):
-            info = pickle.load(open(cache_file, "rb"))
-            if info != None:
+            with open(cache_file, "rb") as c:
+                info = pickle.load(c)
+            if info is not None:
                 if info['program_version'] == self.version:
                     return info
                 print("Cache version " + info['program_version'] + " did not match with Program version " + self.version)
                 print("Invalidating cache and reprocessing the image")
-                    # return None
         return None
 
     def delCache(self):
@@ -123,15 +133,15 @@ class QuadrantFolder(object):
         if os.path.exists(cache_path) and os.path.isfile(cache_file):
             os.remove(cache_file)
 
-    def deleteFromDict(self, dict, delStr):
+    def deleteFromDict(self, dicto, delStr):
         """
         Delete a key and value from dictionary
         :param dict: input dictionary
         :param delStr: deleting key
         :return: -
         """
-        if delStr in dict.keys():
-            del dict[delStr]
+        if delStr in dicto:
+            del dicto[delStr]
 
     def process(self, flags):
         """
@@ -162,6 +172,11 @@ class QuadrantFolder(object):
         self.parent.statusPrint("")
 
     def updateInfo(self, flags):
+        """
+        Update info dict using flags
+        :param flags: flags
+        :return: -
+        """
         if flags['orientation_model'] is None:
             if 'orientation_model' not in self.info:
                 flags['orientation_model'] = 0
@@ -174,8 +189,8 @@ class QuadrantFolder(object):
         Initial some parameters in case GUI doesn't specified
         """
         if 'mask_thres' not in self.info:
-            self.info['mask_thres'] = 0 #getMaskThreshold(self.orig_img, self.img_type)
-        if 'ignore_folds' not  in self.info:
+            self.info['mask_thres'] = getMaskThreshold(self.orig_img, self.img_type)
+        if 'ignore_folds' not in self.info:
             self.info['ignore_folds'] = set()
         if 'bgsub' not in self.info:
             self.info['bgsub'] = 0
@@ -183,6 +198,10 @@ class QuadrantFolder(object):
             self.info['sigmoid'] = 0.05
 
     def applyBlankImageAndMask(self):
+        """
+        Apply the blank image and mask threshold on the orig_img
+        :return: -
+        """
         if 'blank_mask' in self.info and self.info['blank_mask'] and not self.masked:
             img = np.array(self.orig_img, 'float32')
             blank, mask = getBlankImageAndMask(self.img_path)
@@ -201,10 +220,12 @@ class QuadrantFolder(object):
 
     def findCenter(self):
         """
-       Find center of the diffraction. The center will be kept in self.info["center"].
-       Once the center is calculated, the rotation angle will be re-calculated, so self.info["rotationAngle"] is deleted
-       """
+        Find center of the diffraction. The center will be kept in self.info["center"].
+        Once the center is calculated, the rotation angle will be re-calculated, so self.info["rotationAngle"] is deleted
+        """
         self.parent.statusPrint("Finding Center...")
+        if 'mask_thres' not in self.info:
+            self.initParams()
         if 'center' in self.info:
             self.centerChanged = False
             return
@@ -220,7 +241,7 @@ class QuadrantFolder(object):
             self.info['center'] = self.info['manual_center']
             return
         print("Center is being calculated ... ")
-        self.orig_img, self.orig_image_center = processImageForIntCenter(self.orig_img, getCenter(self.orig_img), self.img_type, self.info["mask_thres"])
+        self.orig_img, self.orig_image_center = processImageForIntCenter(self.orig_img, getCenter(self.orig_img), self.img_type, self.info['mask_thres'])
         self.info['center'] = self.orig_image_center
         print("Done. Center = "+str(self.info['center']))
 
@@ -236,7 +257,7 @@ class QuadrantFolder(object):
             del self.info['manual_rotationAngle']
             self.deleteFromDict(self.info, 'avg_fold')
         elif "mode_angle" in self.info:
-            print("Using mode orientation {}".format(self.info["mode_angle"]))
+            print(f'Using mode orientation {self.info["mode_angle"]}')
             self.info['rotationAngle'] = self.info["mode_angle"]
             self.deleteFromDict(self.info, 'avg_fold')
         elif not self.empty and 'rotationAngle' not in self.info.keys():
@@ -247,7 +268,28 @@ class QuadrantFolder(object):
             self.info['rotationAngle'] = getRotationAngle(img, center, self.info['orientation_model'])
             self.deleteFromDict(self.info, 'avg_fold')
         print("Done. Rotation Angle is " + str(self.info['rotationAngle']) +" degree")
-            
+
+    def getExtentAndCenter(self):
+        """
+        Give the extent and the center of the image in self.
+        :return: extent, center
+        """
+        if self is None:
+            return [0,0], (0,0)
+        if self.orig_image_center is None:
+            self.findCenter()
+            self.statusPrint("Done.")
+        if 'calib_center' in self.info:
+            center = self.info['calib_center']
+        elif 'manual_center' in self.info:
+            center = self.info['manual_center']
+        else:
+            center = self.orig_image_center
+
+        extent = [self.info['center'][0] - center[0], self.info['center'][1] - center[1]]
+
+        return extent, center
+
     def centerizeImage(self):
         """
         Create an enlarged image such that image center is at the center of new image
@@ -282,9 +324,9 @@ class QuadrantFolder(object):
             self.parent.newImgDimension = dim
         else:
             dim = self.parent.newImgDimension
-        new_img = np.zeros((dim,dim))
+        new_img = np.zeros((dim,dim)).astype("float32")
         new_img[0:b,0:l] = img
-        
+
         #Translate image to appropriate position
         transx = int(((dim/2) - center[0]))
         transy = int(((dim/2) - center[1]))
@@ -298,25 +340,26 @@ class QuadrantFolder(object):
                 mask_thres = getMaskThreshold(img, self.img_type)
             mask = np.zeros((new_img.shape[0], new_img.shape[1]), dtype=np.uint8)
             mask[new_img <= mask_thres] = 255
+            cv2.setNumThreads(1) # Added to prevent segmentation fault due to cv2.warpAffine
             translated_Img = cv2.warpAffine(new_img, M, (cols, rows))
             translated_mask = cv2.warpAffine(mask, M, (cols, rows))
             translated_mask[translated_mask > 0.] = 255
             translated_Img[translated_mask > 0] = mask_thres
         else:
+            cv2.setNumThreads(1) # Added to prevent segmentation fault due to cv2.warpAffine
             translated_Img = cv2.warpAffine(new_img,M,(cols,rows))
-        
+
         self.orig_img = translated_Img
         self.info['center'] = (int(dim / 2), int(dim / 2))
         self.center_before_rotation = (int(dim / 2), int(dim / 2))
         print("Dimension of image after centerize ", self.orig_img.shape)
-        
+
 
     def getRotatedImage(self):
         """
         Get rotated image by angle while image = original input image, and angle = self.info["rotationAngle"]
         """
         img = np.array(self.orig_img, dtype="float32")
-
         center = self.info["center"]
         if self.center_before_rotation is not None:
             center = self.center_before_rotation
@@ -324,7 +367,7 @@ class QuadrantFolder(object):
             self.center_before_rotation = center
 
         b, l = img.shape
-        rotImg, newCenter, self.rotMat = rotateImage(img,center, self.info["rotationAngle"], self.img_type, self.info['mask_thres'])
+        rotImg, newCenter, self.rotMat = rotateImage(img, center, self.info["rotationAngle"], self.img_type, self.info['mask_thres'])
 
         # Cropping off the surrounding part since we had already expanded the image to maximum possible extent in centerize image
         bnew, lnew = rotImg.shape
@@ -354,6 +397,7 @@ class QuadrantFolder(object):
             return 2
         if x >= center_x and y >= center_y:
             return 3
+        return -1
 
     def applyAngularBGSub(self):
         """
@@ -376,7 +420,7 @@ class QuadrantFolder(object):
 
         I2D = []
         for deg in range(180, 271):
-            x, I = ai.integrate1d(copy_img, npt_rad, mask=mask, unit="r_mm", method="csr", azimuth_range=(deg, deg+1))
+            _, I = ai.integrate1d(copy_img, npt_rad, mask=mask, unit="r_mm", method="csr", azimuth_range=(deg, deg+1))
             I2D.append(I)
 
         I2D = np.array(I2D)
@@ -435,7 +479,7 @@ class QuadrantFolder(object):
         Apply Circular Background Subtraction to average fold, and save the result to self.info['bgimg1']
         """
         fold = copy.copy(self.info['avg_fold'])
-        center = [fold.shape[1] + .5, fold.shape[0] + .5]
+        # center = [fold.shape[1] + .5, fold.shape[0] + .5]
 
         img = self.makeFullImage(fold)
         img = img.astype("float32")
@@ -448,7 +492,7 @@ class QuadrantFolder(object):
         rmin = float(self.info['rmin'])
         rmax = float(self.info['rmax'])
         bin_size = float(self.info["radial_bin"])
-        smooth = self.info['smooth']
+        smoo = self.info['smooth']
         tension = self.info['tension']
         max_bin = int(np.ceil((rmax - rmin) / bin_size))*10
         max_num = int(np.ceil(rmax * 2 * np.pi))*10
@@ -464,7 +508,7 @@ class QuadrantFolder(object):
         index_bn = np.zeros(max_num, 'f')
 
         ccp13.bgcsym2(ad=ad, b=b,
-                      smoo=smooth,
+                      smoo=smoo,
                       tens=tension,
                       pc1=pc1,
                       pc2=pc2,
@@ -496,7 +540,11 @@ class QuadrantFolder(object):
 
         self.info['bgimg1'] = result
 
-    def applySmoothedBGSub(self, type='gauss'):
+    def applySmoothedBGSub(self, typ='gauss'):
+        """
+        Apply the background substraction smoothed, with default type to gaussian.
+        :param typ: type of the substraction
+        """
         fold = copy.copy(self.info['avg_fold'])
 
         img = self.makeFullImage(fold)
@@ -512,7 +560,7 @@ class QuadrantFolder(object):
         smbuf = np.zeros(maxfunc, 'f')
         vals = np.zeros(20, 'f')
 
-        if type == 'gauss':
+        if typ == 'gauss':
             vals[0] = self.info['fwhm']
             vals[1] = self.info['cycles']
             vals[2] = float(self.info['rmin'])
@@ -581,7 +629,7 @@ class QuadrantFolder(object):
         :return:
         """
         fold = copy.copy(self.info['avg_fold'])
-        center = [fold.shape[1] + .5, fold.shape[0] + .5]
+        # center = [fold.shape[1] + .5, fold.shape[0] + .5]
 
         img = self.makeFullImage(fold)
         width = img.shape[1]
@@ -593,7 +641,7 @@ class QuadrantFolder(object):
         jwid = self.info['win_size_y']
         isep = self.info['win_sep_x']
         jsep = self.info['win_sep_y']
-        smooth = self.info['smooth']
+        smoo = self.info['smooth']
         tension = self.info['tension']
         pc1 = self.info['cirmin'] / 100.
         pc2 = self.info['cirmax'] / 100.
@@ -607,7 +655,7 @@ class QuadrantFolder(object):
                       jwid=jwid,
                       isep=isep,
                       jsep=jsep,
-                      smoo=smooth,
+                      smoo=smoo,
                       tens=tension,
                       pc1=pc1,
                       pc2=pc2,
@@ -643,53 +691,19 @@ class QuadrantFolder(object):
         """
         copy_img = copy.copy(self.info['avg_fold'])
         center = [copy_img.shape[1] - .5, copy_img.shape[0] - .5]
-        npt_rad = int(distance(center, (0, 0)))
+        # npt_rad = int(distance(center, (0, 0)))
 
         ai = AzimuthalIntegrator(detector="agilent_titan")
         ai.setFit2D(100, center[0], center[1])
-        mask = np.zeros((copy_img.shape[0], copy_img.shape[1]))
+        # mask = np.zeros((copy_img.shape[0], copy_img.shape[1]))
 
         start_p = self.info["cirmin"]  # minimum value of circular background subtraction pixel range in percent
         end_p = self.info["cirmax"]  # maximum value of circular background subtraction pixel range in percent
         rmin = self.info["rmin"]  # minimum radius for background subtraction
         rmax = self.info["rmax"]  # maximum radius for background subtraction
         radial_bin = self.info["radial_bin"]
-        smooth = self.info['smooth']
-        tension = self.info['tension']
-
-        # I2D = []
-        # for deg in range(180, 271):
-        #     if deg == 180:
-        #         x, I = ai.integrate1d(copy_img, npt_rad, mask=mask, unit="r_mm", azimuth_range=(deg, deg + 0.5))
-        #     elif deg == 270:
-        #         x, I = ai.integrate1d(copy_img, npt_rad, mask=mask, unit="r_mm", azimuth_range=(deg - 0.5, deg))
-        #     else:
-        #         x, I = ai.integrate1d(copy_img, npt_rad, mask=mask, unit="r_mm", azimuth_range=(deg - 0.5, deg + 0.5))
-        #     I2D.append(I)
-
-        # I2D, tth, chi = ai.integrate2d(copy_img, npt_rad, npt_azim=3600, unit="r_mm", method="csr_ocl")
-        # I2D = np.array(I2D[0:900])
-        # fig = plt.figure()
-        # ax = fig.add_subplot(111)
-        # ax.cla()
-        # ax.imshow(I2D)
-        # fig.show()
-
-        # I2D = np.array(I2D)
-        # xs = []
-        # ys = []
-        #
-        # for r in np.arange(rmin, rmax, radial_bin):
-        #     pixels = I2D[:,r:r+radial_bin]
-        #     pixels = sorted(np.ravel(pixels))
-        #     start_ind = int(round(len(pixels) * start_p / 100.))
-        #     end_ind = int(round(len(pixels) * end_p / 100.))
-        #     if start_ind >= end_ind:
-        #         val = pixels[start_ind]
-        #     else:
-        #         val = np.mean(pixels[start_ind:end_ind])
-        #     xs.append(r+radial_bin/2.)
-        #     ys.append(val)
+        smoo = self.info['smooth']
+        # tension = self.info['tension']
 
         max_pts = (2.*np.pi*rmax / 4. + 10) * radial_bin
         nBin = int((rmax-rmin)/radial_bin)
@@ -697,7 +711,7 @@ class QuadrantFolder(object):
         xs, ys = qfu.getCircularDiscreteBackground(np.array(copy_img, np.float32), rmin, start_p, end_p, radial_bin, nBin, max_pts)
 
         max_distance = int(round(distance(center, (0,0)))) + 10
-        sp = UnivariateSpline(xs, ys, s=smooth)
+        sp = UnivariateSpline(xs, ys, s=smoo)
         newx = np.arange(rmin, rmax)
         interpolate = sp(newx)
 
@@ -705,12 +719,6 @@ class QuadrantFolder(object):
         newy = list(np.zeros(rmin))
         newy.extend(list(interpolate))
         newy.extend(np.zeros(max_distance-rmax))
-        # fig = plt.figure()
-        # ax = fig.add_subplot(111)
-        # ax.plot(xs, ys, "ro", label = "orig")
-        # ax.plot(newx, newy, label = "smooth")
-        # ax.legend()
-        # fig.show()
 
         self.info['bg_line'] = [xs, ys, newx, newy]
         # Create background from spline line
@@ -721,14 +729,13 @@ class QuadrantFolder(object):
 
         # Subtract original average fold by background
         self.info['bgimg1'] = result
-        #
-        # result_path = fullPath(self.img_path, "qf_results")
-        # createFolder(result_path)
-        # background = background.astype("float32")
-        # imsave(fullPath(result_path, "cir_bg.tif"), background)
 
     def getFirstPeak(self, hist):
-        # Start from index 5 and go to the right until slope is less than -10
+        """
+        Find the first peak using the histogram.
+        Start from index 5 and go to the right until slope is less than -10
+        :param hist: histogram
+        """
         for i in range(5, int(len(hist)/2)):
             if hist[i] - hist[i-1] < -10:
                 return i
@@ -736,7 +743,7 @@ class QuadrantFolder(object):
 
     def getRminmax(self):
         """
-        get R-min and R-max for backgroun subtraction process. If these value is changed, background subtracted images need to be reproduced.
+        Get R-min and R-max for background subtraction process. If these value is changed, background subtracted images need to be reproduced.
         """
         self.parent.statusPrint("Finding Rmin and Rmax...")
         print("R-min and R-max is being calculated.")
@@ -758,7 +765,7 @@ class QuadrantFolder(object):
             ai = AzimuthalIntegrator(detector="agilent_titan")
             ai.setFit2D(100, center[0], center[1])
             integration_method = pyFAI.method_registry.IntegrationMethod.select_one_available("csr", 1)
-            x, totalI = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method=integration_method, azimuth_range=(180, 270))
+            _, totalI = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method=integration_method, azimuth_range=(180, 270))
 
             self.info['rmin'] = int(round(self.getFirstPeak(totalI) * 1.5))
             self.info['rmax'] = int(round((min(copy_img.shape[0], copy_img.shape[1]) - 1) * .8))
@@ -787,11 +794,11 @@ class QuadrantFolder(object):
 
         for deg in np.arange(180, 271, 1):
             if deg == 180 :
-                x, I = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method="csr", azimuth_range=(180, 180.5))
+                _, I = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method="csr", azimuth_range=(180, 180.5))
             elif deg == 270:
-                x, I = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method="csr", azimuth_range=(269.5, 270))
+                _, I = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method="csr", azimuth_range=(269.5, 270))
             else:
-                x, I = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method="csr", azimuth_range=(deg-0.5, deg+0.5))
+                _, I = ai.integrate1d(copy_img, npt_rad, unit="r_mm", method="csr", azimuth_range=(deg-0.5, deg+0.5))
 
             hist_y = I[int(rmin):int(rmax+1)]
             hist_y = list(np.concatenate((hist_y, np.zeros(len(hist_x) - len(hist_y)))))
@@ -801,39 +808,10 @@ class QuadrantFolder(object):
             y_pchip = pchip(hull_x, hull_y, hist_x)
             pchiplines.append(y_pchip)
 
-        #
-        # for deg in np.arange(0, 91, 1):
-        #     # for each 1 degree from 0 to 90, get azimuth histogram
-        #     hist_y = []
-        #
-        #     for r in range(rmin, rmax+1):
-        #         x = int(round(1.* r * np.math.cos(np.deg2rad(deg))))
-        #         y = int(round(1.* r * np.math.sin(np.deg2rad(deg))))
-        #         if x > copy_img.shape[1] or y > copy_img.shape[0]:
-        #             break
-        #         hist_y.append(copy_img[copy_img.shape[0]-y-1,copy_img.shape[1]-x-1])
-        #
-        #     # get 1D convex hull pchip line for each azimuth histogram
-        #     hull_x, hull_y = getHull(hist_x, hist_y)
-        #     y_pchip = pchip(hull_x, hull_y, hist_x)
-        #     pchiplines.append(y_pchip)
-
         # Smooth each histogram by radius
         pchiplines = np.array(pchiplines, dtype="float32")
         pchiplines2 = convolve1d(pchiplines, [1,2,1], axis=0)/4.
 
-        # fig = plt.figure()
-        # ax = fig.add_subplot(111)
-        # ax.cla()
-        # ax.imshow(pchiplines)
-        # fig.show()
-        #
-        # fig = plt.figure()
-        # ax = fig.add_subplot(111)
-        # ax.cla()
-        # ax.imshow(pchiplines2)
-        # fig.show()
-
         # Produce Background from each pchip line
         background = qfu.make2DConvexhullBG2(pchiplines2, copy_img.shape[1], copy_img.shape[0], center[0], center[1], rmin, rmax)
 
@@ -846,10 +824,6 @@ class QuadrantFolder(object):
         # Subtract original average fold by background
         result = copy_img - background
 
-        # imsave(fullPath(self.img_path,self.img_name)+".bg.tif", background)
-        # imsave(fullPath(self.img_path, self.img_name) + ".orig.tif", np.array(copy_img, dtype="float32"))
-        # result -= result.min()
-
         self.info['bgimg1'] = result
 
 
@@ -861,7 +835,7 @@ class QuadrantFolder(object):
         if 'avg_fold' not in self.info.keys():
             self.deleteFromDict(self.info, 'rmin')
             self.deleteFromDict(self.info, 'rmax')
-            self.imgResultForDisplay = None
+            # self.imgResultForDisplay = None
             rotate_img = copy.copy(self.getRotatedImage())
             center = self.info['center']
             center_x = int(center[0])
@@ -893,8 +867,7 @@ class QuadrantFolder(object):
 
             # Get average fold from all folds
             self.get_avg_fold(quadrants,fold_height,fold_width)
-
-            if 'resultImg' in self.imgCache.keys():
+            if 'resultImg' in self.imgCache:
                 del self.imgCache['resultImg']
 
             print("Done.")
@@ -911,7 +884,7 @@ class QuadrantFolder(object):
 
         if len(self.info["ignore_folds"]) < 4:
             # if self.info['pixel_folding']:
-            # avarage fold by pixel to pixel by cython
+            # average fold by pixel to pixel by cython
             result = qfu.get_avg_fold_float32(np.array(quadrants, dtype="float32"), len(quadrants), fold_height, fold_width,
                                                   self.info['mask_thres'])
             # else:
@@ -960,7 +933,7 @@ class QuadrantFolder(object):
                 self.info["bgimg2"] = white_tophat(avg_fold, disk(self.info["tophat2"]))
             self.deleteFromDict(self.imgCache, "BgSubFold")
 
-        print("Done")
+        print("Done.")
 
     def mergeImages(self):
         """
@@ -982,10 +955,6 @@ class QuadrantFolder(object):
             self.imgCache['BgSubFold'] = qfu.combine_bgsub_float32(img1, img2, center[0], center[1], sigmoid, rad)
             self.deleteFromDict(self.imgCache, "resultImg")
 
-            # display_test(img1, "in",500)
-            # display_test(img2, "out",500)
-            # display_test(self.imgCache['BgSubFold'], "result",500)
-
         print("Done.")
 
     def generateResultImage(self):
@@ -994,7 +963,7 @@ class QuadrantFolder(object):
         :return:
         """
         self.parent.statusPrint("Generating Resultant Image...")
-        print("Generating result image from avarage fold...")
+        print("Generating result image from average fold...")
         result = self.makeFullImage(copy.copy(self.imgCache['BgSubFold']))
         if 'rotate' in self.info and self.info['rotate']:
             result = np.rot90(result)
@@ -1007,7 +976,6 @@ class QuadrantFolder(object):
         :param fold:
         :return: result image
         """
-
         fold_height = fold.shape[0]
         fold_width = fold.shape[1]
 
@@ -1024,3 +992,11 @@ class QuadrantFolder(object):
         resultImg[fold_height:fold_height * 2, fold_width:fold_width * 2] = buttom_right
 
         return resultImg
+
+    def statusPrint(self, text):
+        """
+        Print the text in the window or in the terminal depending on if we are using GUI or headless.
+        :param text: text to print
+        :return: -
+        """
+        print(text)
