@@ -1,22 +1,49 @@
+"""
+Copyright 1999 Illinois Institute of Technology
+
+Permission is hereby granted, free of charge, to any person obtaining
+a copy of this software and associated documentation files (the
+"Software"), to deal in the Software without restriction, including
+without limitation the rights to use, copy, modify, merge, publish,
+distribute, sublicense, and/or sell copies of the Software, and to
+permit persons to whom the Software is furnished to do so, subject to
+the following conditions:
+
+The above copyright notice and this permission notice shall be
+included in all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+IN NO EVENT SHALL ILLINOIS INSTITUTE OF TECHNOLOGY BE LIABLE FOR ANY
+CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
+TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
+SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+Except as contained in this notice, the name of Illinois Institute
+of Technology shall not be used in advertising or otherwise to promote
+the sale, use or other dealings in this Software without prior written
+authorization from Illinois Institute of Technology.
+"""
+
 import sys
 import os
 import pickle
-import logging
 import glob
 import filecmp
 import collections
-import h5py
 import shutil
-import pyFAI
+import h5py
+from pyFAI import detector_factory
+from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
 import numpy as np
-
+from musclex import __version__
 from musclex.modules.EquatorImage import EquatorImage
 from musclex.modules.QuadrantFolder import QuadrantFolder
 from musclex.modules.DiffractionCentroids import DiffractionCentroids
 from musclex.modules.ProjectionProcessor import ProjectionProcessor
 from musclex.modules.ScanningDiffraction import ScanningDiffraction
-from musclex.csv_manager.CP_CSVManager import CP_CSVManager
-from musclex import __version__
+from musclex.csv_manager.DI_CSVManager import DI_CSVManager
 
 
 def module_test(mode, settings, pickledir, inputpath, compdir=None,
@@ -56,16 +83,16 @@ def module_test(mode, settings, pickledir, inputpath, compdir=None,
     if len(filelist) == 0:
         print("No images found in the input path - please specify a set of test images to input.")
         return
-    failed_tests = {filename : list() for filename in filelist}
+    failed_tests = {filename : [] for filename in filelist}
 
     for filename in filelist:
         pass_file = True
 
         if mode == 'eq':
-            test_object = EquatorImage(inputpath, filename)
+            test_object = EquatorImage(inputpath, filename, None)
             test_name = "EQUATOR IMAGE"
         elif mode == 'qf':
-            test_object = QuadrantFolder(inputpath, filename)
+            test_object = QuadrantFolder(inputpath, filename, None)
             test_name = "QUADRANT FOLDER"
         elif mode == 'dc':
             test_object = DiffractionCentroids(inputpath, [filename], 0,
@@ -83,7 +110,14 @@ def module_test(mode, settings, pickledir, inputpath, compdir=None,
         print("\n\033[3;33m---- Processing file {f} ----\033[0;3140m\n".format(f=filename))
         test_object.process(settings.copy())
         print(test_object.info.keys())
-        results = flatten(test_object.info)
+        res = flatten(test_object.info)
+        results = {}
+        for key in res:
+            if isinstance(res[key], float):
+                # rounding to 2 using round()
+                results[key] = round(res[key], 2)
+            else:
+                results[key] = res[key]
 
         prefix = "_record" if testrecord else "_verify"
         imgname = filename.split('.')[0]
@@ -102,7 +136,7 @@ def module_test(mode, settings, pickledir, inputpath, compdir=None,
                 print("\033[1;31m \nTEST FAILED -- NO TEST PICKLES FOUND --")
                 print("\033[0;3840mNo test pickle files corresponding to " \
                       " version {ver} found in folder {p}." \
-                      "\033[0;3140mDid you run \'python equator_image_test.py testrecord\'" \
+                      "\033[0;3140mDid you run \'python test_utils.py testrecord\'" \
                       " from the MuscleX version you're trying to test against?\n"
                       .format(ver=testversion, p=compdir))
                 pass_test = False
@@ -117,8 +151,8 @@ def module_test(mode, settings, pickledir, inputpath, compdir=None,
             pickle.dump(results[field], picklefile, protocol=2)
             picklefile.close()
             if mode == 'di':
-                cp_csvmgr = CP_CSVManager(dir_path=inputpath)
-                cp_csvmgr.write_new_data(test_object)
+                di_csvmgr = DI_CSVManager(dir_path=inputpath)
+                di_csvmgr.write_new_data(test_object)
 
             if not testrecord:
                 # If the version is present, get the pickle to test against
@@ -140,7 +174,7 @@ def module_test(mode, settings, pickledir, inputpath, compdir=None,
 
                 # If the two files aren't identical, return some error
                 # Program_version is usually contained as well, but do not compare those
-                if field is not 'program_version' and not pass_field:
+                if field != 'program_version' and not pass_field:
                     print("Testing {data} ..... \033[0;31mFAILED\033[0;3140m\033[0;3840m".format(data=field))
                     print("Compare the following files for more information:\n" \
                           "File generated for testing: {p1}\nReference file: {p2}" \
@@ -164,20 +198,20 @@ def module_test(mode, settings, pickledir, inputpath, compdir=None,
     # Remove some cache folders for the two modules that don't have no cache options
     if os.path.exists(os.path.join(inputpath, "eq_cache")):
         shutil.rmtree(os.path.join(inputpath, "eq_cache"))
-    if os.path.exists(os.path.join(inputpath, "cp_cache")):
-        shutil.rmtree(os.path.join(inputpath, "cp_cache"))
+    if os.path.exists(os.path.join(inputpath, "di_cache")):
+        shutil.rmtree(os.path.join(inputpath, "di_cache"))
 
     # Print the results of the test over all files
     if not testrecord:
         if mode == 'di':
             print("\033[3;33mComparing Scanning Diffraction results...\033[0;3140m\n")
-            summ_compare = filecmp.cmp(os.path.join(inputpath, 'cp_results', 'summary.csv'),
-                            os.path.join(inputpath, 'cp_results', 'rcd_summary.csv'))
-            ring_compare = filecmp.cmp(os.path.join(inputpath, 'cp_results', 'rings.csv'),
-                            os.path.join(inputpath, 'cp_results', 'rcd_rings.csv'))
+            summ_compare = filecmp.cmp(os.path.join(inputpath, 'di_results', 'summary.csv'),
+                            os.path.join(inputpath, 'di_results', 'rcd_summary.csv'))
+            ring_compare = filecmp.cmp(os.path.join(inputpath, 'di_results', 'rings.csv'),
+                            os.path.join(inputpath, 'di_results', 'rcd_rings.csv'))
             pass_test = summ_compare and ring_compare
-            os.remove(os.path.join(inputpath, 'cp_results', 'summary.csv'))
-            os.remove(os.path.join(inputpath, 'cp_results', 'rings.csv'))
+            os.remove(os.path.join(inputpath, 'di_results', 'summary.csv'))
+            os.remove(os.path.join(inputpath, 'di_results', 'rings.csv'))
         if pass_test:
             print("\n\033[4;32m---- {} TEST SUCCESSFUL ----\033[0;3140m"
                   .format(test_name))
@@ -192,10 +226,10 @@ def module_test(mode, settings, pickledir, inputpath, compdir=None,
     else:
         print("\033[4;32m ---- Test files written ---- \033[0;3140m")
         if mode == 'di':
-            os.rename(os.path.join(inputpath, 'cp_results', 'summary.csv'),
-                      os.path.join(inputpath, 'cp_results', 'rcd_summary.csv'))
-            os.rename(os.path.join(inputpath, 'cp_results', 'rings.csv'),
-                      os.path.join(inputpath, 'cp_results', 'rcd_rings.csv'))
+            os.rename(os.path.join(inputpath, 'di_results', 'summary.csv'),
+                      os.path.join(inputpath, 'di_results', 'rcd_summary.csv'))
+            os.rename(os.path.join(inputpath, 'di_results', 'rings.csv'),
+                      os.path.join(inputpath, 'di_results', 'rcd_rings.csv'))
         return
 
     return pass_test
@@ -236,7 +270,7 @@ def gpu_device_test():
             return True
         print("OpenCL is installed, but no GPU devices were found. GPU acceleration of pyFAI is unavailable.")
         return False
-    except:
+    except Exception:
         print("\n\033[4;31m---- OPENCL DEVICE TEST FAILED ----\033[0;3140m")
         print("Check to make sure that pyopencl was installed properly or \
               proceed without GPU acceleration if other tests pass.")
@@ -244,13 +278,13 @@ def gpu_device_test():
 
 
 def pyfai_gpu_integrate_test():
-    ai = pyFAI.AzimuthalIntegrator(detector="agilent_titan")
+    ai = AzimuthalIntegrator(detector=detector_factory("agilent_titan"))
     data = np.random.random((2048,2048))
     npt = 1000
     pass_test = True
     try:
-        ai.integrate1d(data, 1000, unit="r_mm", method="csr_ocl")
-    except:
+        ai.integrate1d(data, npt, unit="r_mm", method="csr_ocl")
+    except Exception:
         pass_test = False
 
     if pass_test:
@@ -318,11 +352,11 @@ if __name__=="__main__":
                     pickledir=os.path.join(os.path.dirname(__file__), "eq/test_pickles_settingsA"),
                     inputpath=inpath,
                     testrecord=True)
-        # module_test(mode="eq",
-        #             settings=settingsB,
-        #             pickledir=os.path.join(os.path.dirname(__file__), "eq/test_pickles_settingsB"),
-        #             inputpath=inpath,
-        #             testrecord=True)
+        module_test(mode="eq",
+                    settings=settingsB,
+                    pickledir=os.path.join(os.path.dirname(__file__), "eq/test_pickles_settingsB"),
+                    inputpath=inpath,
+                    testrecord=True)
         module_test(mode="qf",
                     settings=settingsQF,
                     pickledir=os.path.join(os.path.dirname(__file__), "qf/test_pickles_settingsQF"),
@@ -348,36 +382,36 @@ if __name__=="__main__":
                       testrecord=True)
 
     if args[1] == 'testverify':
-        # module_test(mode="eq",
-        #             settings=settingsA,
-        #             pickledir=os.path.join(os.path.dirname(__file__), "eq/tmp_verify_settingsA"),
-        #             inputpath=inpath,
-        #             compdir=os.path.join(os.path.dirname(__file__), "eq/test_pickles_settingsA"),
-        #             testrecord=False)
-        # module_test(mode="eq",
-        #             settings=settingsB,
-        #             pickledir=os.path.join(os.path.dirname(__file__), "eq/tmp_verify_settingsB"),
-        #             inputpath=inpath,
-        #             compdir=os.path.join(os.path.dirname(__file__), "eq/test_pickles_settingsB"),
-        #             testrecord=False)
-        # module_test(mode="qf",
-        #             settings=settingsQF,
-        #             pickledir=os.path.join(os.path.dirname(__file__), "pt/tmp_verify_settingsQF"),
-        #             inputpath=inpath,
-        #             compdir=os.path.join(os.path.dirname(__file__), "pt/test_pickles_settingsQF"),
-        #             testrecord=False)
-        # module_test(mode="dc",
-        #             settings=settingsDC,
-        #             pickledir=os.path.join(os.path.dirname(__file__), "pt/tmp_verify_settingsDC"),
-        #             inputpath=inpath,
-        #             compdir=os.path.join(os.path.dirname(__file__), "pt/test_pickles_settingsDC"),
-        #             testrecord=False)
-        # module_test(mode="pt",
-        #             settings=settingsPT,
-        #             pickledir=os.path.join(os.path.dirname(__file__), "pt/tmp_verify_settingsPT"),
-        #             inputpath=inpath,
-        #             compdir=os.path.join(os.path.dirname(__file__), "pt/test_pickles_settingsPT"),
-        #             testrecord=False)
+        module_test(mode="eq",
+                    settings=settingsA,
+                    pickledir=os.path.join(os.path.dirname(__file__), "eq/tmp_verify_settingsA"),
+                    inputpath=inpath,
+                    compdir=os.path.join(os.path.dirname(__file__), "eq/test_pickles_settingsA"),
+                    testrecord=False)
+        module_test(mode="eq",
+                    settings=settingsB,
+                    pickledir=os.path.join(os.path.dirname(__file__), "eq/tmp_verify_settingsB"),
+                    inputpath=inpath,
+                    compdir=os.path.join(os.path.dirname(__file__), "eq/test_pickles_settingsB"),
+                    testrecord=False)
+        module_test(mode="qf",
+                    settings=settingsQF,
+                    pickledir=os.path.join(os.path.dirname(__file__), "pt/tmp_verify_settingsQF"),
+                    inputpath=inpath,
+                    compdir=os.path.join(os.path.dirname(__file__), "pt/test_pickles_settingsQF"),
+                    testrecord=False)
+        module_test(mode="dc",
+                    settings=settingsDC,
+                    pickledir=os.path.join(os.path.dirname(__file__), "pt/tmp_verify_settingsDC"),
+                    inputpath=inpath,
+                    compdir=os.path.join(os.path.dirname(__file__), "pt/test_pickles_settingsDC"),
+                    testrecord=False)
+        module_test(mode="pt",
+                    settings=settingsPT,
+                    pickledir=os.path.join(os.path.dirname(__file__), "pt/tmp_verify_settingsPT"),
+                    inputpath=inpath,
+                    compdir=os.path.join(os.path.dirname(__file__), "pt/test_pickles_settingsPT"),
+                    testrecord=False)
         module_test(mode="di",
                     settings=settingsDI,
                     pickledir=os.path.join(os.path.dirname(__file__), "di/tmp_verify_settingsDI"),
