@@ -25,10 +25,8 @@ of Technology shall not be used in advertising or otherwise to promote
 the sale, use or other dealings in this Software without prior written
 authorization from Illinois Institute of Technology.
 """
-import matplotlib.pyplot as plt
+
 from .pyqt_utils import *
-import matplotlib.patches as patches
-from ..modules.EquatorImage import getCardiacGraph
 from ..utils.image_processor import *
 
 class EQ_FittingTab(QWidget):
@@ -77,6 +75,7 @@ class EQ_FittingTab(QWidget):
         self.sigmaDSpinBx.setObjectName('sigmaDSpinBx')
         self.editableVars[self.sigmaDSpinBx.objectName()] = None
         self.fixSigmaS = QCheckBox("Fixed Sigma S :")
+        self.fixSigmaS.setChecked(True)
         self.sigmaSSpinBx = QDoubleSpinBox()
         self.sigmaSSpinBx.setEnabled(False)
         self.sigmaSSpinBx.setMinimum(-100)
@@ -153,7 +152,6 @@ class EQ_FittingTab(QWidget):
         # self.fittingTabLayout.addSpacing()
         self.fittingTabLayout.addWidget(self.skeletalGrp, 1, 0)
 
-
     def setAllToolTips(self):
         """
         Set Tooltips for widgets
@@ -170,7 +168,7 @@ class EQ_FittingTab(QWidget):
         self.sigmaSSpinBx.editingFinished.connect(lambda: self.fixedFittingParams('sigmaS', self.sigmaSSpinBx))
         self.fixSigmaC.stateChanged.connect(self.fixSigmaCChecked)
         self.fixSigmaD.stateChanged.connect(self.fixedParamChecked)
-        self.fixSigmaS.stateChanged.connect(self.fixedParamChecked)
+        self.fixSigmaS.stateChanged.connect(self.fixSigmaSChecked)
         self.fixGamma.stateChanged.connect(self.fixedParamChecked)
         self.gammaSpinBx.editingFinished.connect(lambda: self.fixedFittingParams('gamma', self.gammaSpinBx))
 
@@ -183,8 +181,10 @@ class EQ_FittingTab(QWidget):
         self.zlineSpnBx.editingFinished.connect(lambda: self.skeletalChanged('zline', self.zlineSpnBx))
         self.gammaZSpnBx.editingFinished.connect(lambda: self.skeletalChanged('gammaZ', self.gammaZSpnBx))
 
-
     def syncSpinBoxes(self, info):
+        """
+        Synchronize spin boxes
+        """
         self.syncUI = True
         side = self.side
         self.fixSigmaC.setChecked(side + '_fix_sigmac' in info)
@@ -211,6 +211,9 @@ class EQ_FittingTab(QWidget):
         self.syncUI = False
 
     def initSpinBoxes(self, info):
+        """
+        Initialize spin box
+        """
         self.syncUI = True
         side = self.side
         if 'fit_results' in info:
@@ -275,6 +278,9 @@ class EQ_FittingTab(QWidget):
         self.syncUI = False
 
     def fixSigmaCChecked(self):
+        """
+        Triggered when fix sigma C is checked
+        """
         side = self.side
         parent = self.parent
         if self.fixSigmaC.isChecked():
@@ -283,6 +289,21 @@ class EQ_FittingTab(QWidget):
         else:
             if side+'_fix_sigmac' in parent.bioImg.info:
                 del parent.bioImg.info[side+'_fix_sigmac']
+        self.sigmaCSpinBx.setEnabled(self.fixSigmaC.isChecked())
+    
+    def fixSigmaSChecked(self):
+        """
+        Triggered when fix sigma S is checked
+        """
+        side = self.side
+        parent = self.parent
+        if self.fixSigmaS.isChecked():
+            if side+'_sigmas' in parent.bioImg.info:
+                del parent.bioImg.info[side+'_sigmas']
+        else:
+            if side+'_fix_sigmas' in parent.bioImg.info:
+                del parent.bioImg.info[side+'_fix_sigmas']
+        self.sigmaSSpinBx.setEnabled(self.fixSigmaS.isChecked())
 
     def fixedParamChecked(self):
         """
@@ -300,7 +321,7 @@ class EQ_FittingTab(QWidget):
         """
         Fixed Value Changed. Remove fit_results from info dict to make it be re-calculated
         """
-        #self.parent.refreshAllFittingParams()
+        # self.parent.refreshAllFittingParams()
         self.log_changes(name, elem, prefix='(fitting)')
 
     def skeletalChecked(self):
@@ -369,19 +390,28 @@ class EQ_FittingTab(QWidget):
         return settings
 
     def init_logging(self):
+        """
+        Initialize the logging
+        """
         for objName in self.editableVars:
             self.editableVars[objName] = self.findChild(QAbstractSpinBox, objName).value()
         #print(self.side, self.editableVars)
 
     def write_log(self, msg):
+        """
+        Write the log
+        """
         if hasattr(self.parent.__class__, 'write_log') and \
            callable(getattr(self.parent.__class__, 'write_log')):
             self.parent.write_log(self.side + ' ' + msg)
 
     def log_changes(self, name, obj, prefix=''):
+        """
+        Change the log file and rewrite it
+        """
         newValue = obj.value()
         varName = obj.objectName()
         if self.editableVars[varName] == newValue:
             return
-        self.write_log('{0}{1}Changed: {2} -> {3}'.format(prefix, name, self.editableVars[varName], newValue))
+        self.write_log(f'{prefix}{name}Changed: {self.editableVars[varName]} -> {newValue}')
         self.editableVars[varName] = newValue
